==> sghi_core-0.2.27.tar.gz: lib/communities/core/endpoints.dart <==
import 'package:sghi_core/communities/core/constants.dart';

const String createRoomEndpoint =
    '$kMatrixHomeServer/_matrix/client/v3/createRoom';
const String loginEndpoint = '$kMatrixHomeServer/_matrix/client/v3/login';
const String listRoomsEndpoint =
    '$kMatrixHomeServer/_matrix/client/v3/joined_rooms';

String stateEventEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state';

String joinedMembersEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/joined_members';

String syncEndpoint = '$kMatrixHomeServer/_matrix/client/v3/sync';

String stateEventsEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state';

String roomMessageEventsEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/messages';

String sendMessageEventEndpoint(String roomID, String txnID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/send/m.room.message/$txnID';

String searchMembersEndpoint =
    '$kMatrixHomeServer/_matrix/client/v3/user_directory/search';

String inviteUserToRoomEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/invite';

String fetchMediaEndpoint(String mediaID) =>
    '$kMatrixHomeServer/_matrix/media/v3/download/$kMatrixMediaServer/$mediaID';

String deleteMessageEventEndpoint(
  String roomID,
  String txnID,
  String eventID,
) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/redact/$eventID/$txnID} ';

String roomPowerLevelsEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state/m.room.power_levels/';

String joinRoomEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/join';

String kickUserEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/kick';

String leaveRoomEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/leave';

String uploadMediaEndpoint = '$kMatrixHomeServer/_matrix/media/v3/upload';

String promoteUserToModeratorEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state/power_levels/';

String banUserEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/ban';

String unBanUserEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/unban';

String reportMessageEndpoint({
  required String roomID,
  required String eventID,
}) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/report/$eventID';

==> sghi_core-0.2.28.tar.gz: lib/communities/core/endpoints.dart <==
import 'package:sghi_core/communities/core/constants.dart';

const String createRoomEndpoint =
    '$kMatrixHomeServer/_matrix/client/v3/createRoom';
const String loginEndpoint = '$kMatrixHomeServer/_matrix/client/v3/login';
const String listRoomsEndpoint =
    '$kMatrixHomeServer/_matrix/client/v3/joined_rooms';

String joinedMembersEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/joined_members';

String syncEndpoint = '$kMatrixHomeServer/_matrix/client/v3/sync';

String stateEventsEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state';

String roomMessageEventsEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/messages';

String sendMessageEventEndpoint(String roomID, String txnID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/send/m.room.message/$txnID';

String searchMembersEndpoint =
    '$kMatrixHomeServer/_matrix/client/v3/user_directory/search';

String inviteUserToRoomEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/invite';

String fetchMediaEndpoint(String mediaID) =>
    '$kMatrixHomeServer/_matrix/media/v3/download/$kMatrixMediaServer/$mediaID';

String deleteMessageEventEndpoint(
  String roomID,
  String txnID,
  String eventID,
) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/redact/$eventID/$txnID} ';

String roomPowerLevelsEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state/m.room.power_levels/';

String joinRoomEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/join';

String kickUserEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/kick';

String leaveRoomEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/leave';

String uploadMediaEndpoint = '$kMatrixHomeServer/_matrix/media/v3/upload';

String promoteUserToModeratorEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/state/power_levels/';

String banUserEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/ban';

String unBanUserEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/unban';

String bannedMembersEndpoint(String roomID) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/members?membership=ban';

String reportMessageEndpoint({
  required String roomID,
  required String eventID,
}) =>
    '$kMatrixHomeServer/_matrix/client/v3/rooms/$roomID/report/$eventID';
